@@ -87,7 +87,7 @@ NULL
 utils::globalVariables(c("time", "value", "Species", "w", "gear", "Age",
                          "x", "y", "Year", "Yield", "Biomass", "Size",
                          "Proportion", "Prey", "Legend", "Type", "Gear",
-                         "Predator", "weight", "a", "b", "age"))
+                         "Predator", "weight", "a", "b", "age", "w_max"))
 
 #' Make a plot from a data frame
 #'
@@ -461,6 +461,8 @@ plotlyYield <- function(sim, sim2,
 #' 
 #' @param sim An object of class \linkS4class{MizerSim}
 #' @inheritParams plotSpectra
+#' @param gears A vector of gear names to be included in the plot. Default is
+#'  all gears.
 #'
 #' @return A ggplot2 object, unless `return_data = TRUE`, in which case a data
 #'   frame with the four variables 'Year', 'Yield', 'Species' and 'Gear' is
@@ -481,6 +483,7 @@ plotlyYield <- function(sim, sim2,
 #' }
 plotYieldGear <- function(sim,
                           species = NULL,
+                          gears = NULL,
                           total = FALSE,
                           highlight = NULL, return_data = FALSE,
                           ...) {
@@ -489,10 +492,11 @@ plotYieldGear <- function(sim,
                 is.flag(return_data))
     params <- sim@params
     species <- valid_species_arg(sim, species, error_on_empty = TRUE)
+    gears <- valid_gears_arg(sim, gears, error_on_empty = TRUE)
     
     y <- getYieldGear(sim, ...)
     y_total <- rowSums(y, dims = 2)
-    y <- y[, , dimnames(y)$sp %in% species, drop = FALSE]
+    y <- y[, dimnames(y)$gear %in% gears, dimnames(y)$sp %in% species, drop = FALSE]
     names(dimnames(y))[names(dimnames(y)) == "sp"] <- "Species"
     ym <- reshape2::melt(y)
     if (total) {
@@ -1077,9 +1081,9 @@ plotlyFMort <- function(object, species = NULL,
 #' on the x-axis. But to follow the usual convention from age-based models, we
 #' plot size on the y-axis and age on the x-axis.
 #'
-#' When the growth curve for only a single species is plotted, horizontal lines
-#' are included that indicate the maturity size and the maximum size for that
-#' species, as well as a vertical line indicating the maturity age.
+#' In each panel for a single species, a horizontal line is included that
+#' indicate the maturity size of the species and a vertical line indicating its
+#' maturity age.
 #' 
 #' If size at age data is passed via the `size_at_age` argument, this is plotted
 #' on top of the growth curve. When comparing this to the growth curves, you
@@ -1223,9 +1227,6 @@ plotGrowthCurves <- function(object, species = NULL,
     if (!percentage)  {
         if (length(species) == 1) {
             idx <- which(sp$species == species)
-            w_max <- sp$w_max[idx]
-            p <- p + geom_hline(yintercept = w_max, colour = "grey") + 
-                annotate("text", 0, w_max, vjust = -1, label = "Maximum")
             w_mat <- sp$w_mat[idx]
             age_mat <- sp$age_mat[idx]
             p <- p + geom_hline(yintercept = w_mat, linetype = "dashed", 
