@@ -1,23 +1,23 @@
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  install.packages("mizer")
 
 ## -----------------------------------------------------------------------------
 library(mizer)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  install.packages("devtools")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  devtools::install_github("sizespectrum/mizer")
 
 ## -----------------------------------------------------------------------------
 params <- newCommunityParams()
 
 ## -----------------------------------------------------------------------------
-params <- newMultispeciesParams(NS_species_params, inter)
+params <- newMultispeciesParams(NS_species_params, NS_interaction)
 
 ## -----------------------------------------------------------------------------
-sim <- project(params, t_max = 10, effort = 0)
+sim <- project(params, t_max = 10, effort = 1)
 
 ## -----------------------------------------------------------------------------
 plot(sim)
