@@ -1,6 +1,4 @@
-context("project method")
-
-params <- newMultispeciesParams(NS_species_params_gears, inter)
+params <- newMultispeciesParams(NS_species_params_gears, inter, info_level = 0)
 
 # time dimension ----
 test_that("time dimension is dealt with properly", {
@@ -106,7 +104,7 @@ test_that("Can pass in initial species", {
     effort[,2] <- 0.5
     effort[,3] <- seq(from = 1, to = 0.5, length = nrow(effort))
     effort[,4] <- 0
-    expect_that(project(params, effort = effort), throws_error())
+    expect_error(project(params, effort = effort))
 })
 
 
@@ -114,10 +112,10 @@ test_that("Can pass in initial species", {
 test_that("w_min array reference is working OK", {
     NS_species_params_gears$w_min <- 0.001
     NS_species_params_gears$w_min[1] <- 1
-    params2 <- newMultispeciesParams(NS_species_params_gears, inter)
+    params2 <- newMultispeciesParams(NS_species_params_gears, inter, info_level = 0)
     sim <- project(params2, effort = 1, t_max = 5)
-    expect_equivalent(sim@n[6, 1, 1:(sim@params@w_min_idx[1] - 1)],
-                      rep(0, sim@params@w_min_idx[1] - 1))
+    expect_equal(sim@n[6, 1, 1:(sim@params@w_min_idx[1] - 1)],
+                      rep(0, sim@params@w_min_idx[1] - 1), ignore_attr = TRUE)
 })
 
 
@@ -221,10 +219,13 @@ test_that("Gear checking and sorting is OK", {
 # same numerical results as previously ----
 test_that("Simulation gives same numerical results as previously",{
   params <- newMultispeciesParams(NS_species_params_gears, inter,
-                                  n = 2/3, p = 0.7, lambda = 2.8 - 2/3)
+                                  n = 2/3, p = 0.7, lambda = 2.8 - 2/3, info_level = 0)
   sim <- project(params, t_max = 1)
-  expect_known_value(sim@n[2, 3, ], "values/projectn")
-  expect_known_value(sim@n_pp[2, ], "values/projectp")
+  # expect_known_value(sim@n[2, 3, ], "values/projectn")
+  # expect_known_value(sim@n_pp[2, ], "values/projectp")
+  expect_snapshot(sim@n[2, 3, ])
+  expect_snapshot(sim@n_pp[2, ])
+  
 })
 
 test_that("Final result the same when called with sim or params", {
