@@ -10,8 +10,8 @@ test_that("get_time_elements", {
     expect_identical(sum(get_time_elements(sim, 3:4)), 3L)
     expect_error(get_time_elements(sim, 3:50), 
                  "Time range is outside the time range of the model")
-    expect_equivalent(which(get_time_elements(sim, seq(3, 4, by = 0.1))), 
-                      c(7, 8, 9))
+    expect_equal(which(get_time_elements(sim, seq(3, 4, by = 0.1))), 
+                      c(7, 8, 9), ignore_attr = TRUE)
     # What if real years are used
     effort <- array(1, dim = c(19, 4),
                     dimnames = list(year = seq(1960, 1969, by = 0.5), 
@@ -20,7 +20,7 @@ test_that("get_time_elements", {
                                     )
                     )
     sim <- project(params, effort = effort, t_save = 0.5)
-    expect_equivalent(which(get_time_elements(sim, 1965)), 11)
-    expect_equivalent(which(get_time_elements(sim, "1965")), 11)
-    expect_equivalent(which(get_time_elements(sim, 1965:1969)), 11:19)
+    expect_equal(which(get_time_elements(sim, 1965)), 11, ignore_attr = TRUE)
+    expect_equal(which(get_time_elements(sim, "1965")), 11, ignore_attr = TRUE)
+    expect_equal(which(get_time_elements(sim, 1965:1969)), 11:19, ignore_attr = TRUE)
 })
